#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-sapic
version:              1.12.0
visibility:           public
id:                   tamarin-prover-sapic-1.12.0-7WOI4RlfbR2A1prOibjOWn
key:                  tamarin-prover-sapic-1.12.0-7WOI4RlfbR2A1prOibjOWn
license:              LicenseRef-GPL
copyright:
    Robert Künnemann, Alexander Dax, CISPA-Helmholtz-Centre Saarbrücken, 2019

maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Alexander Dax <alexander.dax@cispa.saarland>

homepage:             https://tamarin-prover.github.io/
synopsis:
    Library for input processes in SAPIC calculus for the tamarin prover.

description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides a translation from processes stated in the SAPIC calculus into multiset rewrite rules.

category:             Theorem Provers
abi:                  483013d45e110a13d2d6331d60b0603f
exposed:              True
exposed-modules:
    Sapic Sapic.Annotation Sapic.Basetranslation Sapic.Bindings
    Sapic.Compression Sapic.Exceptions Sapic.Facts Sapic.LetDestructors
    Sapic.Locks Sapic.ProcessUtils Sapic.ProgressFunction
    Sapic.ProgressTranslation Sapic.ReliableChannelTranslation
    Sapic.Report Sapic.SecretChannels Sapic.States Sapic.Typing
    Sapic.Warnings

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tamarin-prover-sapic-1.12.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tamarin-prover-sapic-1.12.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tamarin-prover-sapic-1.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-sapic
hs-libraries:         HStamarin-prover-sapic-1.12.0-7WOI4RlfbR2A1prOibjOWn
depends:
    aeson-2.2.2.0-p30NU7EGMRKoAj5LcAXNN
    aeson-pretty-0.8.11-5yNxg5K05cuJ34M8hAr7Gl base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    dlist-1.0-F3vtDhl0dJJ2wapcm5Bnp exceptions-0.10.7 mtl-2.3.1
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD parsec-3.1.16.1
    process-1.6.19.0 raw-strings-qq-1.1-HgsCJbBD5QVLggpDhmUWHl
    safe-0.3.21-CNekTOvlOCxBWhpb53aZQe
    tamarin-prover-term-1.12.0-3IiX8JWBWe0DqkMQNYt1l1
    tamarin-prover-theory-1.12.0-KeLCG0lNaHJAakspGeuHTQ
    tamarin-prover-utils-1.12.0-B42YeXsyWfeB0i49V7K0tv text-2.0.2
    transformers-0.6.1.0 uniplate-1.6.13-AzjlWyYh2ZSH2gzxES4aea

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-sapic/html/tamarin-prover-sapic.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-sapic/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

